@@ -21,7 +21,7 @@ labkey.getQueries <- function(baseUrl, folderPath, schemaName)
 	return(mydata)
 }
 
-## public function  getQueryViews, returns all views associated with a specified query 
+## public function getQueryViews, returns all views associated with a specified query
 labkey.getQueryViews <- function(baseUrl, folderPath, schemaName, queryName)
 {
 	if(is.null(queryName)==FALSE) {char <- nchar(queryName); if(char<1){queryName<-NULL}}
@@ -33,7 +33,6 @@ labkey.getQueryViews <- function(baseUrl, folderPath, schemaName, queryName)
 
 getQueryLists <- function(baseUrl, folderPath, schemaName, queryName=NULL)
 {
-
 	if((length(queryName)>0) && (queryName==curlUnescape(queryName)) ) { queryName <- curlEscape(queryName) }
 	## Error if any of baseUrl, folderPath, or schemName are missing
 	if(exists("baseUrl")==FALSE || exists("folderPath")==FALSE || exists("schemaName")==FALSE )
@@ -54,59 +53,23 @@ getQueryLists <- function(baseUrl, folderPath, schemaName, queryName=NULL)
 	if(length(queryName)==0)
 	{
 		serverAction <- "getQueries.view?schemaName="
-		qParam<-""
+		qParam <- ""
 		queryObjType <- "queries"
-		columnNames<- c("queryName", "fieldName")
+		columnNames <- c("queryName", "fieldName")
 	}
 	else
 	{
 		serverAction <- "getQueryViews.api?schemaName="  
 		qParam <- paste("&queryName=",queryName, sep="")
 		queryObjType <- "views"
-		columnNames<- c("viewName", "fieldName")
+		columnNames <- c("viewName", "fieldName")
 	}
 
 	## Construct url
-	myurl <- paste(baseUrl,"query",folderPath, serverAction, schemaName, qParam, "&apiVersion=8.3", sep="")
+	myurl <- paste(baseUrl, "query", folderPath, serverAction, schemaName, qParam, "&apiVersion=8.3", sep="")
 
-	## Set options
-	reader <- basicTextGatherer()
-	header <- basicTextGatherer()
-    myopts <- curlOptions(netrc=1, writefunction=reader$update, headerfunction=header$update, .opts=c(labkey.curlOptions()))
-
-	## Support user-settable options for debuggin and setting proxies etc
-	if(exists(".lksession"))
-	{
-		userOpt <- .lksession[["curlOptions"]] 
-		if (!is.null(userOpt))
-			{myopts<- curlOptions(.opts=c(myopts, userOpt))}
-	}
-
-	## Http get
-	handle <- getCurlHandle()
-	clist <- ifcookie()
-	if(clist$Cvalue==1) {mydata <- getURI(myurl, .opts=myopts, cookie=paste(clist$Cname,"=",clist$Ccont,sep=""))} else {mydata <- getURI(myurl, .opts=myopts, curl=handle)}
-
-	## Error checking, decode data and return data frame
-	h <- parseHeader(header$value())
-	status <- getCurlInfo(handle)$response.code
-	message <- h$statusMessage
-
-	if(status==500)
-	{decode <- fromJSON(mydata); message <- decode$exception; stop(paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))}
-	if(status>=400)
-	{
-	    contTypes <- which(names(h)=='Content-Type')
-	    if(length(contTypes)>0 && (tolower(h[contTypes[1]])=="application/json;charset=utf-8" || tolower(h[contTypes[2]])=="application/json;charset=utf-8"))
-		{
-		    decode <- fromJSON(mydata);
-		    message<-decode$exception;
-		    stop (paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))
-        } else
-	    {
-	        stop(paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))
-        }
-    }
+	## Execute via our standard GET function
+	mydata <- labkey.get(myurl);
 
 	decode <- fromJSON(mydata)
 	qs <- decode[[queryObjType]]
